@@ -9,13 +9,13 @@ from django.urls import reverse
 
 import datetime, importlib, os, sys
 
-from .utils import generate_xlsx, get_params_for_search
+from .utils import generate_xlsx, get_params_for_search, apply_translations
 
 # Create your views here.
 
 
-def general_obj_new(request, Obj, ObjForm, callback_prevalidation=False, \
-        callback_postvalidation=False, \
+def general_obj_new(request, Obj, ObjForm, translations={}, \
+        callback_prevalidation=False, callback_postvalidation=False, \
         callback_postaction=False, callback_postsaveaction=False, \
         cancel_url=False, return_url=False, html_scripts=False, *args, **kwargs):
     """General form view for adding new objects
@@ -79,20 +79,22 @@ def general_obj_new(request, Obj, ObjForm, callback_prevalidation=False, \
             return HttpResponseRedirect(reverse(ret_dic['class_name'].lower(), \
                     args=(obj.id,)))
         else:
-            ret_dic['form'] = ObjForm(request.POST, request=request)
+            ret_dic['form'] = apply_translations(\
+                    ObjForm(request.POST, request=request), translations)
             return render(request, 'generalobj_new.html', \
                     ret_dic)
     else:
-        ret_dic['form'] = ObjForm(request=request)
+        ret_dic['form'] = apply_translations(ObjForm(request=request), \
+                translations)
         return render(request, 'generalobj_new.html', ret_dic)
 
     return HttpResponse('qqq')
 
 
 def general_obj_edit(request, Obj, ObjForm, general_obj_id, querysets=[], \
-        callback_prevalidation=False, callback_postvalidation=False, \
-        callback_postaction=False, callback_postsaveaction=False, \
-        cancel_url=False, return_url=False):
+        translations={}, callback_prevalidation=False, \
+        callback_postvalidation=False, callback_postaction=False, \
+        callback_postsaveaction=False, cancel_url=False, return_url=False):
     """General form view for editing a record of an object
     
         It' s not a real view, rather a generic function to edit objects with the predefined parameters:
@@ -126,7 +128,8 @@ def general_obj_edit(request, Obj, ObjForm, general_obj_id, querysets=[], \
                 else:
                     return HttpResponseRedirect(reverse(\
                             ret_dic['class_name'].lower(), args=(obj.id,)))
-        form = ObjForm(request.POST, instance=obj, request=request)
+        form = apply_translations(ObjForm(\
+                request.POST, instance=obj, request=request), translations)
         if callback_prevalidation:
             form = callback_prevalidation(form)
             if isinstance(obj, HttpResponseRedirect):
@@ -163,10 +166,11 @@ def general_obj_edit(request, Obj, ObjForm, general_obj_id, querysets=[], \
                         ret_dic['class_name'].lower(), args=(obj.id,)))
         else:
             form = ObjForm(request.POST, instance=obj, request=request)
-            ret_dic['form'] = form
+            ret_dic['form'] = apply_translations(form, translations)
             return render(request, 'generalobj_new.html', ret_dic)
     else:
-        form = ObjForm(instance=obj, request=request)
+        form = apply_translations(ObjForm(instance=obj, request=request), \
+                translations)
         for qs in querysets:
             form.fields[qs[0]].queryset = qs[1]
         ret_dic['form'] = form
